  /*------------------------------------------------------------------*
			     TERM1.C

      The following code shows how to take advantage of some of
      the Turbo C extensions to the C language to do asynchronous
      communications without having to write supporting assembly-
      language routines.

      This program bypasses the less-than-adequate PC BIOS
      communications routines and installs a serial interrupt
      handler. Direct access to PC hardware allows the program to
      run at faster baud rates and eliminates the need for
      the main program to continuously poll the serial port for
      data; thus implementing background communications. Data that
      enters the serial port is stored in a circular buffer.

      * Compile this program with Test Stack Overflow OFF.

      This program is based on SERIAL.C (downloaded from the Borland Inc.
      BBS) and has been modified to accomidate the MCG-2.  All of the
      "low level" MCG-2 communication routines are keep in MCG.H

      This program assumes that an MCG-2 will be operating at 9600 baud,
      8 data bits, no parity, 1 stop bit, and be connected to serial
      port "COM1:".  Also assumed is that the MCG-2 device address is
      "01".

      This program performs as a simple dumb terminal, however, the
      basic functions in this program can be used to write custom
      applications for the MCG-2.

      This program is software ver. 1.04, valid for ROM software version
      1.06 and later.  (C) 19973 by BURST ELECTRONICS Inc

      This example program may be freely copied and modified for
      use with the MCG-2.

      This example program written especially for use with the MCG-2.



  *------------------------------------------------------------------*/

#include <dos.h>
#include <conio.h>
#include <stdio.h>
#include <string.h>
#include "serial.h"
#include "mcg.h"

main()
{
    /* Communications parameters (Default values for MCG-2) */
    int        port     = COM1;
    int        speed    = 9600;
    int        parity   = NO_PARITY;
    int        bits     = 8;
    int        stopbits = 1;

    /* MCG-2 network parameters */
    char        mcg_addr[] = "01";

    int        c, done  = FALSE;


    /* Use ANSI code to clear the PC screen, then print title and ver. numbers */
    fprintf(stdout, "[2J\n\n                              MCG-2 TERMINAL\n"
		    "                             (C) 1998 by BEI.\n\n"
		    "     Version 1.03, Valid for ROM software version 1.06, Using port COM1:\n\n"
		    "Press [ESC] to quit...\n\n");

    if (SetSerial(port, speed, parity, bits, stopbits) != 0)
    {
        fprintf(stderr, "Serial Port setup error.\n");
        return (99);
    }

    initserial();

    ctrlbrk(c_break);

    delay(1000);

    /*
	Wake the MCG-2.
    */
	wake_mcg(mcg_addr);

    /*
	Be sure MCG-2 responses are ON.
    */

	set_res_mcg(0x01);


    /*
       The main loop acts as a dumb terminal. We repeatedly
       check the keyboard buffer, and communications buffer.
    */
    do {
        if (kbhit())
        {
            /* Look for an Escape key */
            switch (c=getch())
            {
                case ESC: done = TRUE;  /* Exit program */
                          break;

                /* You may want to handle other keys here... */
			}
			if (!done)
				SerialOut(c);
        }
        if ((c=getccb()) != -1)
            fputc(c , stdout);

    } while (!done && !SError);

    /* Check for errors */
    switch (SError)
    {
        case NOERROR: fprintf(stderr, "\nbye.\n");
                      closeserial();
                      return (0);

        case BUFOVFL: fprintf(stderr, "\nBuffer Overflow.\n");
                      closeserial();
                      return (99);

        default:      fprintf(stderr, "\nUnknown Error, SError = %d\n",
                              SError);
                      closeserial();
                      return (99);
    }
}


